@@ -30,7 +30,7 @@ import java.util.Map;
  * text is rendered using an AWT font.
  *
  * @author <a href="mailto:bella.robinson@cmis.csiro.au">Bella Robinson</a>
- * @version $Id: ArabicTextHandler.java 1808977 2017-09-20 09:06:07Z ssteiner $
+ * @version $Id$
  */
 public final class ArabicTextHandler {
 
@@ -620,6 +620,12 @@ public final class ArabicTextHandler {
 
         null,                                          // 0x0628
         null,                                          // 0x0629
+        null,                                          // 0x062A
+        null,                                          // 0x062B
+        null,                                          // 0x062C
+        null,                                          // 0x062D
+        null,                                          // 0x062E
+        null,                                          // 0x062F
         null,                                          // 0x0630
         null,                                          // 0x0631
         null,                                          // 0x0632
