@@ -92,7 +92,7 @@ import org.apache.batik.util.ParsedURL;
  *     to use when processing the SVG documents.</li>
  * </ul>
  *
- * @version $Id: SVGConverter.java 1871084 2019-12-09 12:24:18Z ssteiner $
+ * @version $Id$
  * @author <a href="mailto:Henri.Ruini@nokia.com">Henri Ruini</a>
  * @author <a href="mailto:vhardy@apache.org">Vincent Hardy</a>
  */
@@ -253,7 +253,7 @@ public class SVGConverter {
         the document which references them. */
     protected boolean constrainScriptOrigin = true;
 
-    protected boolean allowExternalResources = true;
+    protected boolean allowExternalResources;
 
     /** Controls whether scripts should be run securely or not */
     protected boolean securityOff = false;
@@ -927,8 +927,8 @@ public class SVGConverter {
             map.put(ImageTranscoder.KEY_CONSTRAIN_SCRIPT_ORIGIN, Boolean.FALSE);
         }
 
-        if (!allowExternalResources) {
-            map.put(ImageTranscoder.KEY_ALLOW_EXTERNAL_RESOURCES, Boolean.FALSE);
+        if (allowExternalResources) {
+            map.put(ImageTranscoder.KEY_ALLOW_EXTERNAL_RESOURCES, Boolean.TRUE);
         }
 
         return map;
